===========================================
``teslajsonpy.homeassistant.binary_sensor``
===========================================

.. automodule:: teslajsonpy.homeassistant.binary_sensor

   .. contents::
      :local:

.. currentmodule:: teslajsonpy.homeassistant.binary_sensor
